extras property
The rating of the media item. A map of additional metadata for the media item.
The values must be of type int, String, bool or double.
Implementation
// final Rating? rating;
/// A map of additional metadata for the media item.
///
/// The values must be of type `int`, `String`, `bool` or `double`.
final Map<String, dynamic>? extras;